package production

import (
	"shylinux.com/x/ice"
	kit "shylinux.com/x/toolkits"

	"shylinux.com/x/operation/src/operation"
	"shylinux.com/x/operation/src/production/model"
)

type Table struct {
	operation.Table
	list string `name:"list story_uid uid auto" role:"void"`
}

func (s Table) Inputs(m *ice.Message, arg ...string) {
	switch arg[0] {
	case model.USER_STORY_ROLE:
		s.InputsListRole(m, UserStoryRoleList, arg...)
	case model.STORY_TYPE:
		s.InputsList(m, StoryTypeList, arg...)
	case model.PLAN_UID:
		s.Fields(m, model.UID, model.TITLE)
		m.Cmdy(plan{}, s.Select, m.OptionSimple(model.STORY_UID)).RenameAppend(model.UID, arg[0])
		m.DisplayInputKeyNameIconTitle()
	case model.ISSUE_TYPE:
		s.InputsList(m, IssueTypeList, arg...)
	case model.LEVEL:
		s.InputsList(m, LevelList, arg...)
	default:
		s.Table.Inputs(m, arg...)
	}
}
func (s Table) RewriteAppend(m *ice.Message, arg ...string) *ice.Message {
	m.RewriteAppend(func(value, key string, index int) string {
		switch key {
		case model.USER_STORY_ROLE:
			value = UserStoryRole(kit.Int(value)).String()
		case model.STORY_TYPE:
			value = StoryType(kit.Int(value)).String()
		case model.PLAN_STATUS:
			value = PlanStatus(kit.Int(value)).String()
		case model.ISSUE_TYPE:
			value = IssueType(kit.Int(value)).String()
		case model.ISSUE_STATUS:
			value = IssueStatus(kit.Int(value)).String()
		case model.TASK_STATUS:
			value = TaskStatus(kit.Int(value)).String()
		case model.CASE_STATUS:
			value = CaseStatus(kit.Int(value)).String()
		case model.LEVEL:
			value = Level(kit.Int(value)).String()
		}
		return value
	})
	return s.Table.RewriteAppend(m)
}
func (s Table) SelectJoinPlan(m *ice.Message, arg ...string) {
	s.SelectJoin(m, plan{}, model.TITLE)
}
func (s Table) ChangeStatus(m *ice.Message, from, to int, arg ...string) {
	s.Table.ChangeStatus(m, m.Option(model.STORY_UID), m.Option(model.UID), from, to, arg...)
	s.DashboardUpdate(m)
}
func (s Table) planCount(m *ice.Message, key, value string) {
	if m.IsErr() || m.Option(model.PLAN_UID) == "" {
		return
	}
	m.Cmd(plan{}, s.AddCount, key, value, m.Option(model.PLAN_UID))
}

type Tables struct{ Table }

func (s Tables) BeforeMigrate(m *ice.Message, arg ...string) {}

type Level int

const (
	Level1 Level = iota
	Level2
	Level3
	Level4
	Level5
)

var LevelList = map[Level]string{
	Level1: "level-1",
	Level2: "level-2",
	Level3: "level-3",
	Level4: "level-4",
	Level5: "level-5",
}

func (s Level) String() string { return LevelList[s] }
